@@ -15,6 +15,6 @@
 
 # This script is executed inside gate_hook function in devstack gate.
 
-export REQUIREMENTS_MODE=soft
+export KEEP_LOCALRC=1
 
 $BASE/new/devstack-gate/devstack-vm-gate.sh
