@@ -33,11 +33,17 @@ class Pipeline(api_types.Base):
     trigger_uri = wtypes.text
     """The trigger uri used to trigger the pipeline."""
 
+    last_execution = wtypes.text
+    """The UUID of the last run execution."""
+
     @classmethod
     def from_db_model(cls, m, host_url):
         obj = super(Pipeline, cls).from_db_model(m, host_url)
+        le_obj = m.last_execution()
+        if le_obj is not None:
+            obj.last_execution = le_obj.uuid
         obj.plan_uri = '%s/v1/plans/%s' % (host_url, m.plan_uuid)
-        obj.trigger_uri = '%s/v1/public/triggers/%s' % (host_url, m.trigger_id)
+        obj.trigger_uri = '%s/v1/triggers/%s' % (host_url, m.trigger_id)
         return obj
 
     @classmethod
@@ -46,7 +52,8 @@ class Pipeline(api_types.Base):
                    type='pipeline',
                    name='Example-pipeline',
                    description='A pipeline for my app',
-                   trigger_uri='http://example.com/v1/public/triggers/1abc234',
+                   trigger_uri='http://example.com/v1/triggers/1abc234',
+                   last_execution='78f41cf46df7430b9486a35f5d28a41',
                    tags=['small'],
                    project_id='1dae5a09ef2b4d8cbf3594b0eb4f6b94',
                    user_id='55f41cf46df74320b9486a35f5d28a11',
