@@ -12,11 +12,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import sys
+
 import pecan
 from pecan import rest
-import sys
 import wsmeext.pecan as wsme_pecan
-import yaml
 
 from solum.api.controllers.v1.datamodel import plan
 from solum.api.handlers import plan_handler
@@ -44,6 +44,13 @@ def init_plan_by_version(yml_input_plan):
     return getattr(mod, 'init_plan_v%s' % version)(yml_input_plan)
 
 
+def yaml_content(m):
+    ref_content = m.refined_content()
+    ref_content['uri'] = '%s/v1/plans/%s' % (pecan.request.host_url,
+                                             m.uuid)
+    return ref_content
+
+
 class PlanController(rest.RestController):
     """Manages operations on a single plan."""
 
@@ -56,7 +63,7 @@ class PlanController(rest.RestController):
     def get(self):
         """Return this plan."""
         handler = plan_handler.PlanHandler(pecan.request.security_context)
-        plan_yml = yaml.dump(handler.get(self._id).refined_content())
+        plan_yml = yamlutils.dump(yaml_content(handler.get(self._id)))
         pecan.response.status = 200
         return plan_yml
 
@@ -69,10 +76,11 @@ class PlanController(rest.RestController):
         try:
             yml_input_plan = yamlutils.load(pecan.request.body)
         except ValueError as excp:
-            raise exception.BadRequest('Plan is invalid. ' + excp.message)
+            raise exception.BadRequest(reason='Plan is invalid. '
+                                              + excp.message)
         handler, data = init_plan_by_version(yml_input_plan)
-        updated_plan_yml = yaml.dump(handler.update(
-            self._id, data.as_dict(objects.registry.Plan)).refined_content())
+        updated_plan_yml = yamlutils.dump(yaml_content(handler.update(
+            self._id, data.as_dict(objects.registry.Plan))))
         pecan.response.status = 200
         return updated_plan_yml
 
@@ -102,10 +110,11 @@ class PlansController(rest.RestController):
         try:
             yml_input_plan = yamlutils.load(pecan.request.body)
         except ValueError as excp:
-            raise exception.BadRequest('Plan is invalid. ' + excp.message)
+            raise exception.BadRequest(reason='Plan is invalid. '
+                                              + excp.message)
         handler, data = init_plan_by_version(yml_input_plan)
-        create_plan_yml = yaml.dump(handler.create(
-            data.as_dict(objects.registry.Plan)).refined_content())
+        create_plan_yml = yamlutils.dump(yaml_content(handler.create(
+            data.as_dict(objects.registry.Plan))))
         pecan.response.status = 201
         return create_plan_yml
 
@@ -114,8 +123,8 @@ class PlansController(rest.RestController):
     def get_all(self):
         """Return all plans, based on the query provided."""
         handler = plan_handler.PlanHandler(pecan.request.security_context)
-        plan_yml = yaml.dump([obj.refined_content()
-                              for obj in handler.get_all()
-                              if obj and obj.raw_content])
+        plan_yml = yamlutils.dump([yaml_content(obj)
+                                   for obj in handler.get_all()
+                                   if obj and obj.raw_content])
         pecan.response.status = 200
         return plan_yml
