@@ -32,6 +32,9 @@ API_SERVICE_OPTS = [
     cfg.StrOpt('image_format',
                default='qcow2',
                help='The format of the image to output'),
+    cfg.StrOpt('source_format',
+               default='heroku',
+               help='The format of source repository'),
 ]
 
 LOG = logging.getLogger(__name__)
@@ -92,12 +95,12 @@ class AssemblyHandler(handler.Handler):
         ksc = solum_keystoneclient.KeystoneClientV3(self.context)
         ksc.delete_trust(db_obj.trust_id)
 
-        deploy_api.API(context=self.context).delete_heat_stack(
-            assem_id=db_obj.id)
-
         db_obj.status = ASSEMBLY_STATES.DELETING
         db_obj.save(self.context)
 
+        deploy_api.API(context=self.context).delete_heat_stack(
+            assem_id=db_obj.id)
+
     def create(self, data):
         """Create a new resource."""
         db_obj = objects.registry.Assembly()
@@ -116,11 +119,21 @@ class AssemblyHandler(handler.Handler):
 
         plan_obj = objects.registry.Plan.get_by_id(self.context,
                                                    db_obj.plan_id)
+
         artifacts = plan_obj.raw_content.get('artifacts', [])
         for arti in artifacts:
             self._build_artifact(db_obj, arti)
         return db_obj
 
+    def _unittest_artifact(self, assem, artifact):
+        git_url = artifact['content']['href']
+        test_cmd = artifact.get('unittest_cmd')
+
+        api.API(context=self.context).unittest(
+            assembly_id=assem.id,
+            git_url=git_url,
+            test_cmd=test_cmd)
+
     def _build_artifact(self, assem, artifact):
         # This is a tempory hack so we don't need the build client
         # in the requirments.
@@ -128,13 +141,15 @@ class AssemblyHandler(handler.Handler):
         image.name = artifact['name']
         image.source_uri = artifact['content']['href']
         image.base_image_id = artifact.get('language_pack', 'auto')
-        image.source_format = 'heroku'
+        image.source_format = artifact.get('artifact_type',
+                                           CONF.api.source_format)
         image.image_format = CONF.api.image_format
         image.uuid = str(uuid.uuid4())
         image.user_id = self.context.user
         image.project_id = self.context.tenant
         image.state = IMAGE_STATES.PENDING
         image.create(self.context)
+        test_cmd = artifact.get('unittest_cmd')
 
         api.API(context=self.context).build(
             build_id=image.id,
@@ -143,7 +158,8 @@ class AssemblyHandler(handler.Handler):
             base_image_id=image.base_image_id,
             source_format=image.source_format,
             image_format=image.image_format,
-            assembly_id=assem.id)
+            assembly_id=assem.id,
+            test_cmd=test_cmd)
 
     def get_all(self):
         """Return all assemblies, based on the query provided."""
