@@ -34,9 +34,11 @@ class InfrastructureStackHandler(handler.Handler):
 
     def update(self, id, data):
         """Modify a stack."""
-        updated = objects.registry.InfrastructureStack.update_and_save(
-            self.context, id, data)
-        return updated
+        db_obj = objects.registry.InfrastructureStack.get_by_uuid(
+            self.context, id)
+        db_obj.update(data)
+        db_obj.save(self.context)
+        return db_obj
 
     def delete(self, id):
         """Delete a stack."""
@@ -47,7 +49,7 @@ class InfrastructureStackHandler(handler.Handler):
     def create(self, data):
         """Create a new stack.
 
-        Create a new infrastructure stack by using Heat. Note that a zaqar
+        Create a new infrastructure stack by using Heat. Note that a marconi
         queue is created and will be consumed by solum-infra-guestagent.
         """
         db_obj = objects.registry.InfrastructureStack()
@@ -56,15 +58,15 @@ class InfrastructureStackHandler(handler.Handler):
         db_obj.user_id = self.context.user
         db_obj.project_id = self.context.tenant
 
-        self._create_zaqar_queue(db_obj.uuid)
+        self._create_marconi_queue(db_obj.uuid)
         db_obj.heat_stack_id = self._deploy_infra(data.get('image_id'))
 
         db_obj.create(self.context)
         return db_obj
 
-    def _create_zaqar_queue(self, queue_name):
+    def _create_marconi_queue(self, queue_name):
         osc = clients.OpenStackClients(self.context)
-        osc.zaqar().queue(queue_name)
+        osc.marconi().queue(queue_name)
 
     def _deploy_infra(self, image_id):
         osc = clients.OpenStackClients(self.context)
