@@ -25,18 +25,12 @@ class PlanHandler(handler.Handler):
         """Return a plan."""
         return objects.registry.Plan.get_by_uuid(self.context, id)
 
-    def _update_raw_content(self, db_obj, data):
-        filtered_data = {}
-        for dk, dv in iter(data.items()):
-            if not hasattr(db_obj, dk) and dk not in ('type', 'uri'):
-                filtered_data[dk] = dv
-        db_obj.raw_content = filtered_data
-
     def update(self, id, data):
         """Modify a resource."""
         db_obj = objects.registry.Plan.get_by_uuid(self.context, id)
-        db_obj.update(data)
-        self._update_raw_content(db_obj, data)
+        if 'name' in data:
+            db_obj.name = data['name']
+        db_obj.raw_content.update(data)
         db_obj.save(self.context)
         return db_obj
 
@@ -48,8 +42,9 @@ class PlanHandler(handler.Handler):
     def create(self, data):
         """Create a new resource."""
         db_obj = objects.registry.Plan()
-        db_obj.update(data)
-        self._update_raw_content(db_obj, data)
+        if 'name' in data:
+            db_obj.name = data['name']
+        db_obj.raw_content = data
         db_obj.uuid = str(uuid.uuid4())
         db_obj.user_id = self.context.user
         db_obj.project_id = self.context.tenant
