@@ -14,7 +14,6 @@
 
 """Solum Deployer noop handler."""
 
-from solum.openstack.common.gettextutils import _
 from solum.openstack.common import log as logging
 
 LOG = logging.getLogger(__name__)
@@ -22,8 +21,8 @@ LOG = logging.getLogger(__name__)
 
 class Handler(object):
     def echo(self, ctxt, message):
-        LOG.debug(_("%s") % message)
+        LOG.debug("%s" % message)
 
     def deploy(self, ctxt, assembly_id, image_id):
         message = ("Deploy %s %s" % (assembly_id, image_id))
-        LOG.debug(_("%s") % message)
+        LOG.debug("%s" % message)
