@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -22,7 +24,6 @@ from solum.tests import base
 from solum.tests import fakes
 
 
-@mock.patch('solum.common.policy.check')
 @mock.patch('pecan.request', new_callable=fakes.FakePecanRequest)
 @mock.patch('pecan.response', new_callable=fakes.FakePecanResponse)
 @mock.patch('solum.api.handlers.assembly_handler.AssemblyHandler')
@@ -31,9 +32,7 @@ class TestAssemblyController(base.BaseTestCase):
         super(TestAssemblyController, self).setUp()
         objects.load()
 
-    def test_assembly_get(self, AssemblyHandler, resp_mock,
-                          request_mock, mock_policy):
-        mock_policy.return_value = True
+    def test_assembly_get(self, AssemblyHandler, resp_mock, request_mock):
         hand_get = AssemblyHandler.return_value.get
         fake_assembly = fakes.FakeAssembly()
         hand_get.return_value = fake_assembly
@@ -47,14 +46,11 @@ class TestAssemblyController(base.BaseTestCase):
         self.assertEqual(fake_assembly.user_id, resp['result'].user_id)
         self.assertEqual(fake_assembly.application_uri,
                          resp['result'].application_uri)
-        self.assertEqual(fake_assembly.created_at, resp['result'].created_at)
-        self.assertEqual(fake_assembly.updated_at, resp['result'].updated_at)
         hand_get.assert_called_with('test_id')
         self.assertEqual(200, resp_mock.status)
 
     def test_assembly_get_not_found(self, AssemblyHandler,
-                                    resp_mock, request_mock, mock_policy):
-        mock_policy.return_value = True
+                                    resp_mock, request_mock):
         hand_get = AssemblyHandler.return_value.get
         hand_get.side_effect = exception.ResourceNotFound(
             name='assembly', assembly_id='test_id')
@@ -63,9 +59,7 @@ class TestAssemblyController(base.BaseTestCase):
         hand_get.assert_called_with('test_id')
         self.assertEqual(404, resp_mock.status)
 
-    def test_assembly_put_none(self, AssemblyHandler, resp_mock,
-                               request_mock, mock_policy):
-        mock_policy.return_value = True
+    def test_assembly_put_none(self, AssemblyHandler, resp_mock, request_mock):
         request_mock.body = None
         request_mock.content_type = 'application/json'
         hand_put = AssemblyHandler.return_value.put
@@ -74,8 +68,7 @@ class TestAssemblyController(base.BaseTestCase):
         self.assertEqual(400, resp_mock.status)
 
     def test_assembly_put_not_found(self, AssemblyHandler,
-                                    resp_mock, request_mock, mock_policy):
-        mock_policy.return_value = True
+                                    resp_mock, request_mock):
         json_update = {'name': 'foo'}
         request_mock.body = json.dumps(json_update)
         request_mock.content_type = 'application/json'
@@ -86,9 +79,7 @@ class TestAssemblyController(base.BaseTestCase):
         hand_update.assert_called_with('test_id', json_update)
         self.assertEqual(404, resp_mock.status)
 
-    def test_assembly_put_ok(self, AssemblyHandler, resp_mock,
-                             request_mock, mock_policy):
-        mock_policy.return_value = True
+    def test_assembly_put_ok(self, AssemblyHandler, resp_mock, request_mock):
         json_update = {'name': 'foo'}
         request_mock.body = json.dumps(json_update)
         request_mock.content_type = 'application/json'
@@ -99,8 +90,7 @@ class TestAssemblyController(base.BaseTestCase):
         self.assertEqual(200, resp_mock.status)
 
     def test_assembly_delete_not_found(self, AssemblyHandler,
-                                       resp_mock, request_mock, mock_policy):
-        mock_policy.return_value = True
+                                       resp_mock, request_mock):
         hand_delete = AssemblyHandler.return_value.delete
         hand_delete.side_effect = exception.ResourceNotFound(
             name='assembly', assembly_id='test_id')
@@ -110,8 +100,7 @@ class TestAssemblyController(base.BaseTestCase):
         self.assertEqual(404, resp_mock.status)
 
     def test_assembly_delete_ok(self, AssemblyHandler,
-                                resp_mock, request_mock, mock_policy):
-        mock_policy.return_value = True
+                                resp_mock, request_mock):
         hand_delete = AssemblyHandler.return_value.delete
         hand_delete.return_value = None
         obj = assembly.AssemblyController('test_id')
@@ -147,7 +136,6 @@ class TestAssemblyAsDict(base.BaseTestCase):
         self.assertEqual(self.data, s.as_dict(objects.registry.Assembly))
 
 
-@mock.patch('solum.common.policy.check')
 @mock.patch('pecan.request', new_callable=fakes.FakePecanRequest)
 @mock.patch('pecan.response', new_callable=fakes.FakePecanResponse)
 @mock.patch('solum.api.handlers.assembly_handler.AssemblyHandler')
@@ -157,8 +145,7 @@ class TestAssembliesController(base.BaseTestCase):
         objects.load()
 
     def test_assemblies_get_all(self, AssemblyHandler,
-                                resp_mock, request_mock, mock_policy):
-        mock_policy.return_value = True
+                                resp_mock, request_mock):
         hand_get = AssemblyHandler.return_value.get_all
         fake_assembly = fakes.FakeAssembly()
         hand_get.return_value = [fake_assembly]
@@ -177,8 +164,7 @@ class TestAssembliesController(base.BaseTestCase):
 
     @mock.patch('solum.objects.registry.Plan')
     def test_assemblies_post(self, mock_Plan, AssemblyHandler,
-                             resp_mock, request_mock, mock_policy):
-        mock_policy.return_value = True
+                             resp_mock, request_mock):
         json_create = {'name': 'foo',
                        'plan_uri': 'http://test_url:8080/test/911'}
         request_mock.body = json.dumps(json_create)
@@ -195,8 +181,7 @@ class TestAssembliesController(base.BaseTestCase):
         self.assertEqual(201, resp_mock.status)
 
     def test_assemblies_post_no_plan(self, AssemblyHandler, resp_mock,
-                                     request_mock, mock_policy):
-        mock_policy.return_value = True
+                                     request_mock):
         json_create = {'name': 'foo'}
         request_mock.body = json.dumps(json_create)
         request_mock.content_type = 'application/json'
@@ -210,8 +195,7 @@ class TestAssembliesController(base.BaseTestCase):
         self.assertEqual(400, resp_mock.status)
 
     def test_assemblies_post_not_hosted(self, AssemblyHandler, resp_mock,
-                                        request_mock, mock_policy):
-        mock_policy.return_value = True
+                                        request_mock):
         json_create = {'name': 'foo',
                        'plan_uri': 'http://example.com/a.git'}
         request_mock.body = json.dumps(json_create)
@@ -223,9 +207,7 @@ class TestAssembliesController(base.BaseTestCase):
         self.assertIn('The plan was not hosted in solum', faultstring)
         self.assertEqual(400, resp_mock.status)
 
-    def test_assem_post_nodata(self, AssemblyHandler, resp_mock,
-                               request_mock, mock_policy):
-        mock_policy.return_value = True
+    def test_assem_post_nodata(self, AssemblyHandler, resp_mock, request_mock):
         request_mock.body = ''
         request_mock.content_type = 'application/json'
         hand_create = AssemblyHandler.return_value.create
