@@ -13,8 +13,8 @@
 # under the License.
 
 import json
-from unittest import mock
 
+import mock
 
 from solum.api.handlers import infrastructure_handler as infra
 from solum.tests import base
@@ -45,14 +45,19 @@ class TestInfrastructureStackHandler(base.BaseTestCase):
         mock_registry.InfrastructureStackList.get_all.assert_called_once_with(
             self.ctx)
 
-    def test_update(self, mock_reg):
+    def test_update(self, mock_registry):
         data = {'user_id': 'new_user_id',
                 'image_id': 'new_image_id',
                 'heat_stack_id': 'new_stack_id'}
+        db_obj = fakes.FakeInfrastructureStack()
+        mock_registry.InfrastructureStack.get_by_uuid.return_value = db_obj
         handler = infra.InfrastructureStackHandler(self.ctx)
-        handler.update('test_id', data)
-        mock_reg.InfrastructureStack.update_and_save.assert_called_once_with(
-            self.ctx, 'test_id', data)
+        res = handler.update('test_id', data)
+        self.assertEqual(db_obj.user_id, res.user_id)
+        db_obj.save.assert_called_once_with(self.ctx)
+        db_obj.update.assert_called_once_with(data)
+        mock_registry.InfrastructureStack.get_by_uuid.assert_called_once_with(
+            self.ctx, 'test_id')
 
     @mock.patch('solum.common.clients.OpenStackClients')
     @mock.patch('solum.common.catalog.get')
@@ -68,7 +73,7 @@ class TestInfrastructureStackHandler(base.BaseTestCase):
         mock_create.return_value = {"stack": {"id": "fake_id",
                                     "links": [{"href": "http://fake.ref",
                                                "rel": "self"}]}}
-        mock_queue = mock_clients.return_value.zaqar.return_value.queue
+        mock_queue = mock_clients.return_value.marconi.return_value.queue
         handler = infra.InfrastructureStackHandler(self.ctx)
         res = handler.create(data)
         db_obj.update.assert_called_once_with(data)
@@ -80,11 +85,11 @@ class TestInfrastructureStackHandler(base.BaseTestCase):
         mock_queue.assert_called_once_with(db_obj.uuid)
 
     @mock.patch('solum.common.clients.OpenStackClients')
-    def test_create_zaqar_queue(self, mock_clients, mock_registry):
+    def test_create_marconi_queue(self, mock_clients, mock_registry):
         queue_name = 'test'
-        mock_queue = mock_clients.return_value.zaqar.return_value.queue
+        mock_queue = mock_clients.return_value.marconi.return_value.queue
         handler = infra.InfrastructureStackHandler(self.ctx)
-        handler._create_zaqar_queue(queue_name)
+        handler._create_marconi_queue(queue_name)
         mock_queue.assert_called_once_with(queue_name)
 
     def test_delete(self, mock_registry):
