@@ -12,6 +12,8 @@
 
 from glanceclient import client as glanceclient
 from heatclient import client as heatclient
+from marconiclient.queues.v1 import client as marconiclient
+from mistralclient.api import client as mistralclient
 import mock
 from neutronclient.neutron import client as neutronclient
 from swiftclient import client as swiftclient
@@ -27,10 +29,10 @@ class ClientsTest(base.BaseTestCase):
     def test_url_for(self, mock_keystone):
         obj = clients.OpenStackClients(None)
         obj.url_for(service_type='fake_service', endpoint_type='fake_endpoint')
-        service_catalog = mock_keystone.return_value.client.service_catalog
-        service_catalog.url_for.assert_called_once_with(
-            service_type='fake_service',
-            endpoint_type='fake_endpoint')
+
+        mock_cat = mock_keystone.return_value.client.service_catalog
+        mock_cat.url_for.assert_called_once_with(service_type='fake_service',
+                                                 endpoint_type='fake_endpoint')
 
     @mock.patch.object(glanceclient, 'Client')
     @mock.patch.object(clients.OpenStackClients, 'url_for')
@@ -50,6 +52,7 @@ class ClientsTest(base.BaseTestCase):
     def test_clients_glance_noauth(self):
         con = mock.MagicMock()
         con.auth_token = None
+        con.auth_token_info = None
         con.tenant = "b363706f891f48019483f8bd6503c54d"
         obj = clients.OpenStackClients(con)
         obj._glance = None
@@ -92,6 +95,7 @@ class ClientsTest(base.BaseTestCase):
     def test_clients_heat_noauth(self):
         con = mock.MagicMock()
         con.auth_token = None
+        con.auth_token_info = None
         con.tenant = "b363706f891f48019483f8bd6503c54b"
         auth_url = mock.PropertyMock(name="auth_url",
                                      return_value="keystone_url")
@@ -135,6 +139,7 @@ class ClientsTest(base.BaseTestCase):
     def test_clients_swift_noauth(self):
         con = mock.MagicMock()
         con.auth_token = None
+        con.auth_token_info = None
         con.tenant = "b363706f891f48019483f8bd6503c54b"
         auth_url = mock.PropertyMock(name="auth_url",
                                      return_value="keystone_url")
@@ -180,6 +185,7 @@ class ClientsTest(base.BaseTestCase):
     def test_clients_neutron_noauth(self):
         con = mock.MagicMock()
         con.auth_token = None
+        con.auth_token_info = None
         con.tenant = "b363706f891f48019483f8bd6503c54b"
         auth_url = mock.PropertyMock(name="auth_url",
                                      return_value="keystone_url")
@@ -203,3 +209,92 @@ class ClientsTest(base.BaseTestCase):
         neutron = obj.neutron()
         neutron_cached = obj.neutron()
         self.assertEqual(neutron, neutron_cached)
+
+    @mock.patch.object(mistralclient, 'Client')
+    @mock.patch.object(clients.OpenStackClients, 'url_for')
+    def test_clients_mistral(self, mock_url, mock_call):
+        con = mock.MagicMock()
+        con.tenant = "b363706f891f48019483f8bd6503c54d"
+        con.auth_token = "3bcc3d3a03f44e3d8377f9247b0ad155"
+        mock_url.return_value = "url_from_keystone"
+        obj = clients.OpenStackClients(con)
+        obj._mistral = None
+        obj.mistral()
+        mock_call.assert_called_once_with(
+            mistral_url='url_from_keystone',
+            auth_token='3bcc3d3a03f44e3d8377f9247b0ad155')
+        mock_url.assert_called_once_with(service_type='workflow',
+                                         endpoint_type='publicURL')
+
+    def test_clients_mistral_noauth(self):
+        con = mock.MagicMock()
+        con.auth_token = None
+        con.auth_token_info = None
+        con.tenant = "b363706f891f48019483f8bd6503c54d"
+        obj = clients.OpenStackClients(con)
+        obj._mistral = None
+        self.assertRaises(exception.AuthorizationFailure, obj.mistral)
+
+    @mock.patch.object(mistralclient, 'Client')
+    @mock.patch.object(clients.OpenStackClients, 'url_for')
+    def test_clients_mistral_cached(self, mock_url, mock_call):
+        con = mock.MagicMock()
+        con.tenant = "b363706f891f48019483f8bd6503c54d"
+        con.auth_token = "3bcc3d3a03f44e3d8377f9247b0ad155"
+        mock_url.return_value = "url_from_keystone"
+        obj = clients.OpenStackClients(con)
+        obj._mistral = None
+        mistral = obj.mistral()
+        mistral_cached = obj.mistral()
+        self.assertEqual(mistral, mistral_cached)
+
+    @mock.patch.object(marconiclient, 'Client')
+    @mock.patch.object(clients.OpenStackClients, 'url_for')
+    @mock.patch.object(clients.OpenStackClients, 'auth_url')
+    def test_clients_marconi(self, mock_auth, mock_url, mock_call):
+        mock_auth.__get__ = mock.Mock(return_value="keystone_url")
+        con = mock.MagicMock()
+        con.tenant = "b363706f891f48019483f8bd6503c54b"
+        con.auth_token = "3bcc3d3a03f44e3d8377f9247b0ad155"
+        con.auth_url = "keystone_url"
+        mock_url.return_value = "url_from_keystone"
+        obj = clients.OpenStackClients(con)
+        obj._marconi = None
+        obj.marconi()
+        conf = {'auth_opts':
+                {'backend': 'keystone',
+                 'options':
+                    {'os_auth_token': '3bcc3d3a03f44e3d8377f9247b0ad155',
+                     'os_auth_url': 'keystone_url',
+                     'insecure': False}
+                 }
+                }
+        mock_call.assert_called_once_with('url_from_keystone', conf=conf)
+
+    def test_clients_marconi_noauth(self):
+        con = mock.MagicMock()
+        con.auth_token = None
+        con.auth_token_info = None
+        con.tenant = "b363706f891f48019483f8bd6503c54b"
+        auth_url = mock.PropertyMock(name="auth_url",
+                                     return_value="keystone_url")
+        type(con).auth_url = auth_url
+        con.get_url_for = mock.Mock(name="get_url_for")
+        con.get_url_for.return_value = "url_from_keystone"
+        obj = clients.OpenStackClients(con)
+        obj._marconi = None
+        self.assertRaises(exception.AuthorizationFailure, obj.marconi)
+
+    @mock.patch.object(clients.OpenStackClients, 'url_for')
+    @mock.patch.object(clients.OpenStackClients, 'auth_url')
+    def test_clients_marconi_cached(self, mock_auth, mock_url):
+        mock_auth.__get__ = mock.Mock(return_value="keystone_url")
+        con = mock.MagicMock()
+        con.tenant = "b363706f891f48019483f8bd6503c54b"
+        con.auth_token = "3bcc3d3a03f44e3d8377f9247b0ad155"
+        mock_url.return_value = "url_from_keystone"
+        obj = clients.OpenStackClients(con)
+        obj._marconi = None
+        marconi = obj.marconi()
+        marconi_cached = obj.marconi()
+        self.assertEqual(marconi, marconi_cached)
