@@ -17,7 +17,10 @@
 import os
 import subprocess
 
+from oslo.config import cfg
+
 import solum
+from solum.common import exception
 from solum.common import solum_keystoneclient
 from solum.conductor import api as conductor_api
 from solum.deployer import api as deployer_api
@@ -31,6 +34,8 @@ LOG = logging.getLogger(__name__)
 ASSEMBLY_STATES = assembly.States
 IMAGE_STATES = image.States
 
+cfg.CONF.import_opt('task_log_dir', 'solum.worker.config', group='worker')
+
 
 def job_update_notification(ctxt, build_id, state=None, description=None,
                             created_image_id=None, assembly_id=None):
@@ -58,6 +63,7 @@ class Handler(object):
     def echo(self, ctxt, message):
         LOG.debug("%s" % message)
 
+    @exception.wrap_keystone_exception
     def _get_environment(self, ctxt):
         kc = solum_keystoneclient.KeystoneClientV3(ctxt)
         image_url = kc.client.service_catalog.url_for(
@@ -72,29 +78,42 @@ class Handler(object):
         user_env['OS_AUTH_TOKEN'] = ctxt.auth_token
         user_env['OS_AUTH_URL'] = ctxt.auth_url
         user_env['OS_IMAGE_URL'] = image_url
+
+        user_env['PROJECT_ID'] = ctxt.tenant
+
+        user_env['BUILD_ID'] = uuidutils.generate_uuid()
+        user_env['SOLUM_TASK_DIR'] = cfg.CONF.worker.task_log_dir
         return user_env
 
+    @property
+    def proj_dir(self):
+        return os.path.abspath(os.path.join(os.path.dirname(__file__),
+                                            '..', '..', '..'))
+
     def _get_build_command(self, ctxt, source_uri, name, base_image_id,
                            source_format, image_format):
-        proj_dir = os.path.abspath(os.path.join(os.path.dirname(__file__),
-                                                '..', '..', '..'))
         # map the input formats to script paths.
         # TODO(asalkeld) we need an "auto".
         pathm = {'heroku': 'lp-cedarish',
                  'dib': 'diskimage-builder',
+                 'dockerfile': 'lp-dockerfile',
                  'docker': 'docker',
                  'qcow2': 'vm-slug'}
         if base_image_id == 'auto' and image_format == 'qcow2':
             base_image_id = 'cedarish'
-        build_app = os.path.join(proj_dir, 'contrib',
+        build_app = os.path.join(self.proj_dir, 'contrib',
                                  pathm.get(source_format, 'lp-cedarish'),
                                  pathm.get(image_format, 'vm-slug'),
                                  'build-app')
-        build_cmd = [build_app, source_uri, name, ctxt.tenant, base_image_id]
-        return build_cmd
+        return [build_app, source_uri, name, ctxt.tenant, base_image_id]
 
     def build(self, ctxt, build_id, source_uri, name, base_image_id,
-              source_format, image_format, assembly_id):
+              source_format, image_format, assembly_id, test_cmd):
+
+        # TODO(datsun180b): This is only temporary, until Mistral becomes our
+        # workflow engine.
+        if self._run_unittest(ctxt, assembly_id, source_uri, test_cmd) != 0:
+            return
 
         update_assembly_status(ctxt, assembly_id, ASSEMBLY_STATES.BUILDING)
 
@@ -107,7 +126,15 @@ class Handler(object):
         solum.TLS.trace.support_info(build_cmd=' '.join(build_cmd),
                                      assembly_id=assembly_id)
 
-        user_env = self._get_environment(ctxt)
+        try:
+            user_env = self._get_environment(ctxt)
+        except exception.SolumException as env_ex:
+            LOG.exception(env_ex)
+            job_update_notification(ctxt, build_id, IMAGE_STATES.ERROR,
+                                    description=str(env_ex),
+                                    assembly_id=assembly_id)
+            return
+
         log_env = user_env.copy()
         if 'OS_AUTH_TOKEN' in log_env:
             del log_env['OS_AUTH_TOKEN']
@@ -116,6 +143,10 @@ class Handler(object):
         job_update_notification(ctxt, build_id, IMAGE_STATES.BUILDING,
                                 description='Starting the image build',
                                 assembly_id=assembly_id)
+        # TODO(datsun180b): Associate log with assembly properly
+        logpath = "%s/%s.log" % (user_env['SOLUM_TASK_DIR'],
+                                 user_env['BUILD_ID'])
+        LOG.debug("Build logs stored at %s" % logpath)
         try:
             out = subprocess.Popen(build_cmd,
                                    env=user_env,
@@ -125,6 +156,7 @@ class Handler(object):
             job_update_notification(ctxt, build_id, IMAGE_STATES.ERROR,
                                     description=subex, assembly_id=assembly_id)
             return
+
         # we expect one line in the output that looks like:
         # created_image_id=<the glance_id>
         created_image_id = None
@@ -141,6 +173,52 @@ class Handler(object):
                                 description='built successfully',
                                 created_image_id=created_image_id,
                                 assembly_id=assembly_id)
-        if assembly_id is not None:
+        if created_image_id is not None:
             deployer_api.API(context=ctxt).deploy(assembly_id=assembly_id,
                                                   image_id=created_image_id)
+
+    def _run_unittest(self, ctxt, assembly_id, git_url, test_cmd):
+        if test_cmd is None:
+            LOG.debug("Unit test command is None; skipping unittests.")
+            return 0
+
+        git_branch = 'master'
+
+        LOG.debug("Running unittests.")
+        update_assembly_status(ctxt, assembly_id, ASSEMBLY_STATES.UNIT_TESTING)
+
+        test_app = os.path.join(self.proj_dir, 'contrib', 'lp-cedarish',
+                                'docker', 'unittest-app')
+        command = [test_app, git_url, git_branch, ctxt.tenant, test_cmd]
+
+        solum.TLS.trace.clear()
+        solum.TLS.trace.import_context(ctxt)
+
+        user_env = self._get_environment(ctxt)
+        log_env = user_env.copy()
+        if 'OS_AUTH_TOKEN' in log_env:
+            del log_env['OS_AUTH_TOKEN']
+        solum.TLS.trace.support_info(environment=log_env)
+
+        logpath = "%s/%s.log" % (user_env['SOLUM_TASK_DIR'],
+                                 user_env['BUILD_ID'])
+        LOG.debug("Unittest logs stored at %s" % logpath)
+
+        returncode = -1
+        try:
+            runtest = subprocess.Popen(command, env=user_env,
+                                       stdout=subprocess.PIPE)
+            returncode = runtest.wait()
+        except OSError as subex:
+            LOG.exception("Exception running unit tests:")
+            LOG.exception(subex)
+
+        if returncode != 0:
+            LOG.error("Unit tests failed. Return code is %r" % (returncode))
+            update_assembly_status(ctxt, assembly_id,
+                                   ASSEMBLY_STATES.UNIT_TESTING_FAILED)
+
+        return returncode
+
+    def unittest(self, ctxt, assembly_id, git_url, test_cmd):
+        self._run_unittest(ctxt, assembly_id, git_url, test_cmd)
